==> patch-2.5.3.18_3.zip: app/templates/default/partials/sideBar.php <==
<?php use Helpers\Url; use Helpers\Session; use Helpers\Auth; ?>
<?php $session = new Session();?>
<div class="sidebar desktop-only">
    <div class="text-center <?php if(D_PROFILE_PIC == false){echo 'hide';}?>" >
        <img class="profileImg sideBarProfilePic toolTip hide" style="cursor: default;" data-placement="right" data-toggle="tooltip" title="<?=$session->get('userName')?>" src="<?=Url::profilePic($session->get('userName'))?>" />
    </div>
    <div class="side-menu">
        <ul class="nav">
            <!-- Side bar Home Button Logic-->
<?php if(DISABLE_BLUVAULT == true && Auth::checkUserPermission('readOnlyAdmin')){ ?>
<li <?php if($data['active'] == 'home'){echo 'class="active"';}?>><a href="<?=Url::basePath('cloudInfo')?>"><i class="fa fa-home"></i></a></li>
<?php } else if(DISABLE_BLUSYNC == true && Auth::checkUserPermission('readOnlyAdmin')){ ?>
<li <?php if($data['active'] == 'home'){echo 'class="active"';}?>><a href="<?=Url::basePath('dashboard')?>"><i class="fa fa-home"></i></a></li>
<?php } else {?>
            <?php if(Auth::checkUserPermission('readOnlyAdmin')){ ?>

                <?php if((Auth::checkCloudPermission('sync') && !Auth::checkCloudPermission('backup')) || (!Auth::checkCloudPermission('sync') && Auth::checkCloudPermission('backup'))){ ?>
                    <li class="hide" <?php if($data['active'] == 'home'){echo 'class="active"';}?>>
                        <?php if(Auth::checkCloudPermission('backup')){ ?>
                            <a href="<?=Url::basePath('dashboard')?>"><i class="fa fa-home"></i></a>
                        <?php } ?>
                        <?php if(Auth::checkCloudPermission('sync')){ ?>
                            <a href="<?=Url::basePath('cloudInfo')?>"><i class="fa fa-home"></i></a>
                        <?php } ?>
                    </li>
                <?php }else{ ?>
                    <li class="hide" <?php if($data['active'] == 'home'){echo 'class="active"';}?>>
                        <a href="#" class="dropdown-toggle" data-toggle="dropdown" role="button" aria-haspopup="true" aria-expanded="true"><i class="fa fa-home"></i></a>
                        <ul class="sideBarDropDown dropdown-menu">
                            <?php if(Auth::checkCloudPermission('sync')){ ?>
                                <li><a href="<?=Url::basePath('cloudInfo')?>"><?php if(BLUDRIVE_MODE == false){ ?> BluSync <?php } else{ ?> BluDrive <?php } ?></a></li>
                            <?php } ?>
                            <?php if(Auth::checkCloudPermission('backup')){ ?>
                                <li><a href="<?=Url::basePath('dashboard')?>">BluVault</a></li>
                            <?php } ?>
                            <?php if(Auth::checkCloudPermission('serverBackup')){ ?>
                                <li><a href="<?=Url::basePath('dashboard')?>">Server Backup</a></li>
                            <?php } ?>
                        </ul>
                    </li>
                <?php }?>
            <?php } ?>
<?php } ?>
<?php if(Auth::checkUserPermission('readOnlyAdmin') || Auth::checkUserPermission('readOnlyAdmin')){ ?>
<li <?php if($data['active'] == 'home'){echo 'class="active"';}?>><a href="<?=Url::basePath('dashboard')?>"><i class="fa fa-home"></i></a></li>
<?php } ?>
<?php if(DISABLE_BLUSYNC == false){ ?>
            <!-- Side bar MySync Button Logic -->
            <?php if(Auth::checkCloudPermission('sync')){ ?>
                <li <?php if($data['active'] == 'sync'){echo 'class="active"';}?>><a class="toolTip" data-toggle="tooltip" data-placement="right" title="<?php if(BLUDRIVE_MODE == true){ echo 'My BluDrive';}else{echo 'My BluSync';}?>" href="<?=Url::basePath('sync/files')?>"><i class="fa fa-files-o"></i></a></li>
            <?php } ?>
<?php } ?>

<?php if(DISABLE_BLUVAULT == false){ ?>
            <?php if(Auth::checkCloudPermission('backup') || Auth::checkCloudPermission('office365')){ ?>
                <!-- Side bar MyBluvault Button Logic -->
                <li <?php if($data['active'] == 'backup'){echo 'class="active"';}?>><a class="toolTip" data-toggle="tooltip" data-placement="right" title="My BluVault" href="<?=Url::basePath('backup/devices')?>"><i class="fa fa-database"></i></a></li>
            <?php } ?>
<?php } ?>

            <!-- Side bar MyBluvault, PMS, Reports, Cloud Settings Button Logic -->
            <?php if(Auth::checkCloudPermission('backup') || Auth::checkCloudPermission('sync') || Auth::checkCloudPermission('office365')){ ?>

                <!-- Side bar Reports Button Logic -->
                <?php if(Auth::checkUserPermission('readOnlyAdmin')){ ?>
                    <li class="hide" <?php if($data['active'] == 'report'){echo 'class="active"';}?>>
                        <a href="#" class="dropdown-toggle" data-toggle="dropdown" role="button" aria-haspopup="true" aria-expanded="true"><i class="fa fa-bar-chart"></i></a>
                        <ul class="sideBarDropDown dropdown-menu">
                            <?php if(Auth::checkCloudPermission('serverBackup')){ ?>
                                <li><a href="<?=Url::basePath('report/dashboard')?>">Server Backup</a></li>
                            <?php } ?>
                            <?php if(Auth::checkCloudPermission('backup')){ ?>
                                <li><a href="<?=Url::basePath('report/dashboard')?>">BluVault</a></li>
                            <?php } ?>
                            <?php if(Auth::checkCloudPermission('sync')){ ?>
                                <li><a href="<?=Url::basePath('report/syncDashboard')?>">BluSync</a></li>
                            <?php } ?>
                        </ul>
                    </li>
                <?php } ?>

            <?php } ?>

            <!-- Side bar Cloud Settings Button Logic -->
            <?php if(Auth::checkUserPermission('admin')){ ?>
                <?php if(CLOUD_SETTINGS == true){ ?>
                    <li <?php if($data['active'] == 'settings'){echo 'class="active"';}?>><a class="toolTip" data-toggle="tooltip" data-placement="right" title="Settings" href="<?=Url::basePath('settings')?>"><i class="fa fa-cogs"></i></a></li>
                <?php } ?>
            <?php } ?>

            <?php if(Auth::checkCloudPermission('backup') || Auth::checkCloudPermission('sync') || Auth::checkCloudPermission('office365')){ ?>
                <!-- Side bar PMS Button Logic -->
                <?php if(Auth::checkUserPermission('admin') || Auth::checkUserPermission('readOnlyAdmin')){ ?>
                    <li <?php if($data['active'] == 'pms'){echo 'class="active"';}?>><a class="toolTip" data-toggle="tooltip" data-placement="right" title="Policy Management" href="<?=Url::basePath('pms')?>"><i class="fa fa-file-powerpoint-o"></i></a></li>
                <?php } ?>
            <?php } ?>

            <?php if(Auth::checkCloudPermission('serverBackup')){ ?>
                <!-- Side bar PMS Button Logic -->
                <?php if($_SESSION['readOnlyAdmin'] != true){ ?>
                    <li <?php if($data['active'] == 'pms'){echo 'class="active"';}?>><a class="toolTip" data-toggle="tooltip" data-placement="right" title="Policy Management" href="<?=Url::basePath('pms')?>"><i class="fa fa-file-powerpoint-o"></i></a></li>
                <?php } ?>
            <?php } ?>

            <!-- Side bar Migration Tool, Users, Devices Button Logic -->
            <?php if(Auth::checkUserPermission('admin') || Auth::checkUserPermission('readOnlyAdmin')){ ?>
                <!-- Side bar Migration Tool Button Logic -->
                <?php if(Auth::checkCloudPermission('sync') || Auth::checkCloudPermission('backup') || Auth::checkCloudPermission('serverBackup') || Auth::checkCloudPermission('office365')){ ?>
                    <?php if($_SESSION['isLdapEnabled'] == 'true' || $_SESSION['isAADEnabled'] == 'true'){ ?>
                        <li <?php if($data['active'] == 'migration'){echo 'class="active"';}?>><a class="toolTip" data-toggle="tooltip" data-placement="right" title="User Migration" href="<?=Url::basePath('migration')?>"><i class="fa fa-exchange"></i></a></li>
                    <?php } ?>
                <?php } ?>

                <!-- Side bar Users Button Logic -->
                <li <?php if($data['active'] == 'users'){echo 'class="active"';}?>><a class="toolTip" data-toggle="tooltip" data-placement="right" title="Users" href="<?=Url::basePath('users')?>"><i class="fa fa-users"></i></a></li>

                <!-- Side bar Devices Button Logic -->
<?php if(DISABLE_BLUVAULT == false){ ?>
                <?php if(Auth::checkCloudPermission('backup') || Auth::checkCloudPermission('office365')){ ?>
                    <li <?php if($data['active'] == 'devices'){echo 'class="active"';}?>><a class="toolTip" data-toggle="tooltip" data-placement="right" title="Devices" href="<?=Url::basePath('devices')?>"><i class="fa fa-desktop"></i></a></li>
                <?php } ?>
<?php } ?>
            <?php } ?>

            <!-- Side bar Devices Button Logic -->
            <?php if(Auth::checkCloudPermission('serverBackup')){ ?>
                <li <?php if($data['active'] == 'servers'){echo 'class="active"';}?>><a class="toolTip" data-toggle="tooltip" data-placement="right" title="Servers" href="<?=Url::basePath('servers')?>"><i class="fa fa-server"></i></a></li>
                <?php if(Auth::checkUserPermission('admin')){ ?>
                    <li <?php if($data['active'] == 'jobs'){echo 'class="active"';}?>><a class="toolTip" data-toggle="tooltip" data-placement="right" title="Jobs" href="<?=Url::basePath('server/jobs')?>"><i class="fa fa-tasks"></i></a></li>
                <?php } ?>
            <?php } ?>

            <!-- Side bar Support Button Logic -->
            <?php if(Auth::checkCloudPermission('backup') || Auth::checkCloudPermission('sync') || Auth::checkCloudPermission('office365')){ ?>
            <?php if(Auth::checkUserPermission('readOnlyAdmin')){ ?>
                <?php if($_SESSION['showSupportPage'] == 'true'){ ?>
                    <li <?php if($data['active'] == 'support'){echo 'class="active"';}?>><a class="toolTip" data-toggle="tooltip" data-placement="right" title="Support" href="<?=Url::basePath('support')?>"><i class="fa fa-support"></i></a></li>
                <?php } ?>
            <?php } ?>
            <?php } ?>
        </ul>
    </div>
</div>

==> patch-2.5.4.6_2.zip: app/templates/default/partials/sideBar.php <==
<?php use Helpers\Url; use Helpers\Session; use Helpers\Auth; ?>
<?php $session = new Session();?>
<div class="sidebar desktop-only">
    <div class="text-center <?php if(D_PROFILE_PIC == false){echo 'd-none';}?>" >
        <img class="profileImg sideBarProfilePic toolTip d-none" style="cursor: default;" data-placement="right" data-toggle="tooltip" title="<?=$session->get('userName')?>" src="<?=Url::profilePic($session->get('userName'))?>" />
    </div>
    <div class="side-menu">
        <ul class="nav">
            <!-- Side bar Home Button Logic-->
<?php if(DISABLE_BLUVAULT == true && Auth::checkUserPermission('readOnlyAdmin')){ ?>
<li <?php if($data['active'] == 'home'){echo 'class="active"';}?>><a href="<?=Url::basePath('cloudInfo')?>"><i class="fa fa-home"></i></a></li>
<?php } else if(DISABLE_BLUSYNC == true && Auth::checkUserPermission('readOnlyAdmin')){ ?>
<li <?php if($data['active'] == 'home'){echo 'class="active"';}?>><a href="<?=Url::basePath('dashboard')?>"><i class="fa fa-home"></i></a></li>
<?php } else {?>
            <?php if(Auth::checkUserPermission('readOnlyAdmin')){ ?>

                <?php if((Auth::checkCloudPermission('sync') && !Auth::checkCloudPermission('backup')) || (!Auth::checkCloudPermission('sync') && Auth::checkCloudPermission('backup'))){ ?>
                    <li class="d-none" <?php if($data['active'] == 'home'){echo 'class="active"';}?>>
                        <?php if(Auth::checkCloudPermission('backup')){ ?>
                            <a href="<?=Url::basePath('dashboard')?>"><i class="fa fa-home"></i></a>
                        <?php } ?>
                        <?php if(Auth::checkCloudPermission('sync')){ ?>
                            <a href="<?=Url::basePath('cloudInfo')?>"><i class="fa fa-home"></i></a>
                        <?php } ?>
                    </li>
                <?php }else{ ?>
                    <li class="d-none" <?php if($data['active'] == 'home'){echo 'class="active"';}?>>
                        <a href="#" class="dropdown-toggle" data-toggle="dropdown" role="button" aria-haspopup="true" aria-expanded="true"><i class="fa fa-home"></i></a>
                        <ul class="sideBarDropDown dropdown-menu">
                            <?php if(Auth::checkCloudPermission('sync')){ ?>
                                <li><a href="<?=Url::basePath('cloudInfo')?>"><?php if(BLUDRIVE_MODE == false){ ?> BluSync <?php } else{ ?> BluDrive <?php } ?></a></li>
                            <?php } ?>
                            <?php if(Auth::checkCloudPermission('backup')){ ?>
                                <li><a href="<?=Url::basePath('dashboard')?>">BluVault</a></li>
                            <?php } ?>
                            <?php if(Auth::checkCloudPermission('serverBackup')){ ?>
                                <li><a href="<?=Url::basePath('dashboard')?>">Server Backup</a></li>
                            <?php } ?>
                        </ul>
                    </li>
                <?php }?>
            <?php } ?>
<?php } ?>
<?php if(Auth::checkUserPermission('readOnlyAdmin') || Auth::checkUserPermission('readOnlyAdmin')){ ?>
<li <?php if($data['active'] == 'home'){echo 'class="active"';}?>><a href="<?=Url::basePath('dashboard')?>"><i class="fa fa-home"></i></a></li>
<?php } ?>
<?php if(DISABLE_BLUSYNC == false){ ?>
            <!-- Side bar MySync Button Logic -->
            <?php if(Auth::checkCloudPermission('sync')){ ?>
                <?php if($_SESSION['syncEnabled'] == 'true'){?>
                    <li <?php if($data['active'] == 'sync'){echo 'class="active"';}?>><a class="toolTip" data-toggle="tooltip" data-placement="right" title="<?php if(BLUDRIVE_MODE == true){ echo 'My BluDrive';}else{echo 'My BluSync';}?>" href="<?=Url::basePath('sync/files')?>"><i class="fa fa-files-o"></i></a></li>
                <?php } ?>
            <?php } ?>
<?php } ?>

<?php if(DISABLE_BLUVAULT == false){ ?>
            <?php if(Auth::checkCloudPermission('backup') || Auth::checkCloudPermission('office365')){ ?>
                <!-- Side bar MyBluvault Button Logic -->
                <li <?php if($data['active'] == 'backup'){echo 'class="active"';}?>><a class="toolTip" data-toggle="tooltip" data-placement="right" title="My BluVault" href="<?=Url::basePath('backup/devices')?>"><i class="fa fa-database"></i></a></li>
            <?php } ?>
<?php } ?>

            <!-- Side bar MyBluvault, PMS, Reports, Cloud Settings Button Logic -->
            <?php if(Auth::checkCloudPermission('backup') || Auth::checkCloudPermission('sync') || Auth::checkCloudPermission('office365')){ ?>

                <!-- Side bar Reports Button Logic -->
                <?php if(Auth::checkUserPermission('readOnlyAdmin')){ ?>
                    <li class="d-none" <?php if($data['active'] == 'report'){echo 'class="active"';}?>>
                        <a href="#" class="dropdown-toggle" data-toggle="dropdown" role="button" aria-haspopup="true" aria-expanded="true"><i class="fa fa-bar-chart"></i></a>
                        <ul class="sideBarDropDown dropdown-menu">
                            <?php if(Auth::checkCloudPermission('serverBackup')){ ?>
                                <li><a href="<?=Url::basePath('report/dashboard')?>">Server Backup</a></li>
                            <?php } ?>
                            <?php if(Auth::checkCloudPermission('backup')){ ?>
                                <li><a href="<?=Url::basePath('report/dashboard')?>">BluVault</a></li>
                            <?php } ?>
                            <?php if(Auth::checkCloudPermission('sync')){ ?>
                                <li><a href="<?=Url::basePath('report/syncDashboard')?>">BluSync</a></li>
                            <?php } ?>
                        </ul>
                    </li>
                <?php } ?>

            <?php } ?>

            <!-- Side bar Cloud Settings Button Logic -->
            <?php if(Auth::checkUserPermission('admin')){ ?>
                <?php if(CLOUD_SETTINGS == true){ ?>
                    <li <?php if($data['active'] == 'settings'){echo 'class="active"';}?>><a class="toolTip" data-toggle="tooltip" data-placement="right" title="Settings" href="<?=Url::basePath('settings')?>"><i class="fa fa-cogs"></i></a></li>
                <?php } ?>
            <?php } ?>

            <?php if(Auth::checkCloudPermission('backup') || Auth::checkCloudPermission('sync') || Auth::checkCloudPermission('office365')){ ?>
                <!-- Side bar PMS Button Logic -->
                <?php if(Auth::checkUserPermission('admin') || Auth::checkUserPermission('readOnlyAdmin')){ ?>
                    <li <?php if($data['active'] == 'pms'){echo 'class="active"';}?>><a class="toolTip" data-toggle="tooltip" data-placement="right" title="Policy Management" href="<?=Url::basePath('pms')?>"><i class="fa fa-file-powerpoint-o"></i></a></li>
                <?php } ?>
            <?php } ?>

            <?php if(Auth::checkCloudPermission('serverBackup')){ ?>
                <!-- Side bar PMS Button Logic -->
                <?php if($_SESSION['readOnlyAdmin'] != true){ ?>
                    <li <?php if($data['active'] == 'pms'){echo 'class="active"';}?>><a class="toolTip" data-toggle="tooltip" data-placement="right" title="Policy Management" href="<?=Url::basePath('pms')?>"><i class="fa fa-file-powerpoint-o"></i></a></li>
                <?php } ?>
            <?php } ?>

            <!-- Side bar Migration Tool, Users, Devices Button Logic -->
            <?php if(Auth::checkUserPermission('admin') || Auth::checkUserPermission('readOnlyAdmin')){ ?>
                <!-- Side bar Migration Tool Button Logic -->
                <?php if(Auth::checkCloudPermission('sync') || Auth::checkCloudPermission('backup') || Auth::checkCloudPermission('serverBackup') || Auth::checkCloudPermission('office365')){ ?>
                    <?php if($_SESSION['isLdapEnabled'] == 'true' || $_SESSION['isAADEnabled'] == 'true'){ ?>
                        <li <?php if($data['active'] == 'migration'){echo 'class="active"';}?>><a class="toolTip" data-toggle="tooltip" data-placement="right" title="User Migration" href="<?=Url::basePath('migration')?>"><i class="fa fa-exchange"></i></a></li>
                    <?php } ?>
                <?php } ?>

                <!-- Side bar Users Button Logic -->
                <li <?php if($data['active'] == 'users'){echo 'class="active"';}?>><a class="toolTip" data-toggle="tooltip" data-placement="right" title="Users" href="<?=Url::basePath('users')?>"><i class="fa fa-users"></i></a></li>

                <!-- Side bar Devices Button Logic -->
<?php if(DISABLE_BLUVAULT == false){ ?>
                <?php if(Auth::checkCloudPermission('backup') || Auth::checkCloudPermission('office365')){ ?>
                    <li <?php if($data['active'] == 'devices'){echo 'class="active"';}?>><a class="toolTip" data-toggle="tooltip" data-placement="right" title="Devices" href="<?=Url::basePath('devices')?>"><i class="fa fa-desktop"></i></a></li>
                <?php } ?>
<?php } ?>
            <?php } ?>

            <!-- Side bar Devices Button Logic -->
            <?php if(Auth::checkCloudPermission('serverBackup')){ ?>
                <li <?php if($data['active'] == 'servers'){echo 'class="active"';}?>><a class="toolTip" data-toggle="tooltip" data-placement="right" title="Servers" href="<?=Url::basePath('servers')?>"><i class="fa fa-server"></i></a></li>
                <?php if(Auth::checkUserPermission('admin')){ ?>
                    <li <?php if($data['active'] == 'jobs'){echo 'class="active"';}?>><a class="toolTip" data-toggle="tooltip" data-placement="right" title="Jobs" href="<?=Url::basePath('server/jobs')?>"><i class="fa fa-tasks"></i></a></li>
                <?php } ?>
            <?php } ?>

            <!-- Side bar Support Button Logic -->
            <?php if(Auth::checkCloudPermission('backup') || Auth::checkCloudPermission('sync') || Auth::checkCloudPermission('office365')){ ?>
            <?php if(Auth::checkUserPermission('readOnlyAdmin')){ ?>
                <?php if($_SESSION['showSupportPage'] == 'true'){ ?>
                    <li <?php if($data['active'] == 'support'){echo 'class="active"';}?>><a class="toolTip" data-toggle="tooltip" data-placement="right" title="Support" href="<?=Url::basePath('support')?>"><i class="fa fa-support"></i></a></li>
                <?php } ?>
            <?php } ?>
            <?php } ?>
        </ul>
    </div>
</div>
